@@ -72,32 +72,23 @@ class DaskGatewaySlurmConfig(sinfo.SInfoTable):
         return
 
 
-class PClusterBackend(SlurmBackend):
+class PClusterConfig(SlurmClusterConfig)
+    """Dask cluster configuration options when running on SLURM"""
+    partition = Unicode("", help="The partition to submit jobs to.", config=True)
+    qos = Unicode("", help="QOS string associated with each job.", config=True)
+    account = Unicode("", help="Account string associated with each job.", config=True)
     constraint = Unicode("", help="The job instance type constraint.", config=True)
-    default_profile: str = None
 
-    @functools.cached_property
-    def cluster_options(self):
-        dask_gateway_slurm_config = DaskGatewaySlurmConfig()
-        profile_names = list(dask_gateway_slurm_config.profiles.keys())
-        if self.default_profile:
-            default_profile = self.default_profile
-        else:
-            default_profile = profile_names[0]
-        Options(
-            Select(
-                "profile",
-                profile_names,
-                default=default_profile,
-                label="Cluster Profile",
-            ),
-            String(
-                "environment",
-                label="Conda Environment"
-            ),
-            handler=lambda options: dask_gateway_slurm_config.profiles[options.profile],
-        )
-        return
+
+class PClusterBackend(SlurmBackend):
+
+    cluster_config_class = Type(
+        "aws_pcluster_dask_gateway.aws_pcluster_dask_gateway.PCLusterConfig",
+        klass="dask_gateway_server.backends.base.ClusterConfig",
+        help="The cluster config class to use",
+        config=True,
+    )
+
 
     def get_submit_cmd_env_stdin(self, cluster, worker=None):
         cmd = [self.submit_command, "--parsable", "--job-name=dask-gateway"]
@@ -165,3 +156,23 @@ class PClusterBackend(SlurmBackend):
 #     ),
 #     handler=lambda options: profiles[options.profile],
 # )
+def cluster_options(default_profile=None):
+    dask_gateway_slurm_config = DaskGatewaySlurmConfig()
+    profile_names = list(dask_gateway_slurm_config.profiles.keys())
+    if not default profile:
+        default_profile = profile_names[0]
+    elif default_profile and default_profile not in profile_names:
+        default_profile = profile_names[0]
+    return Options(
+        Select(
+            "profile",
+            profile_names,
+            default=default_profile,
+            label="Cluster Profile",
+        ),
+        String(
+            "environment",
+            label="Conda Environment"
+        ),
+        handler=lambda options: dask_gateway_slurm_config.profiles[options.profile],
+    )
